Crate vote_commitment_tree_client

Crate vote_commitment_tree_client 

Remote client library for the Zally vote commitment tree.

Provides [HttpTreeSyncApi] — an HTTP implementation of the TreeSyncApi trait that connects to a running Zally chain node’s REST API.

Used by the vote-tree-cli binary and available as a library for integration in other Rust tools.

Modules

types
JSON deserialization types matching the Go chain’s REST API responses.